import logging.handlers


def setup(hub, conf):
    """
    Given the configuration data set up the logger.

    Output to a file that rotates the logs
    """
    root = logging.getLogger()

    raw_level = conf["log_level"].strip().lower()
    if raw_level.isdigit():
        hub.log.INT_LEVEL = int(raw_level)
    else:
        hub.log.INT_LEVEL = hub.log.LEVEL.get(raw_level, root.level)

    root.setLevel(hub.log.INT_LEVEL)
    cf = logging.Formatter(fmt=conf["log_fmt_console"], datefmt=conf["log_datefmt"])
    ch = logging.StreamHandler()
    ch.setLevel(hub.log.INT_LEVEL)
    ch.setFormatter(cf)
    root.addHandler(ch)
    hub.log.handlers.addHandler(ch)

    ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
    _, kwargs = hub.render.cli.args(conf["log_handler_options"])

    mykwargs = {"maxBytes": 100 * 1024 * 1024, "backupCount": 5}
    mykwargs.update(kwargs)

    fh = logging.handlers.RotatingFileHandler(
        filename=conf["log_file"], delay=True, **mykwargs
    )
    fh.setLevel(hub.log.INT_LEVEL)
    fh.setFormatter(ff)
    root.addHandler(fh)
    hub.log.handlers.addHandler(fh)
